namespace Eco.Mods.TechTree
{
    using System.Collections.Generic;
    using System.Linq;
    using Eco.Gameplay.Components;
    using Eco.Gameplay.DynamicValues;
    using Eco.Gameplay.Items;
    using Eco.Gameplay.Players;
    using Eco.Gameplay.Skills;
	using Eco.Gameplay.Systems;
    using Eco.Gameplay.Systems.TextLinks;
    using Eco.Mods.TechTree;
    using Eco.Shared.Items;
    using Eco.Shared.Localization;
    using Eco.Shared.Serialization;
    using Eco.Shared.Utils;
    using Eco.Shared.View;
	using Eco.Gameplay.Objects;
    
    [Serialized]
    [Weight(100)]                                          
    public partial class SushiItem :
        FoodItem            
    {
        public override LocString DisplayName                     { get { return Localizer.DoStr("Sushi"); } }
        public override LocString DisplayDescription                      { get { return Localizer.DoStr("A blend of raw fish and rice."); } }

        private static Nutrients nutrition = new Nutrients()    { Carbs = 14, Fat = 11, Protein = 6, Vitamins = 8};
        public override float Calories                          { get { return 700; } }
        public override Nutrients Nutrition                     { get { return nutrition; } }
    }

    [RequiresSkill(typeof(CulinaryArtsSkill), 2)]    
    public partial class SushiRecipe : Recipe
    {
        public SushiRecipe()
        {
            this.Products = new CraftingElement[]
            {
                new CraftingElement<SushiItem>(),
               
            };
            this.Ingredients = new CraftingElement[]
            {
                new CraftingElement<RawFishItem>(typeof(CulinaryArtsEfficiencySkill), 5, CulinaryArtsEfficiencySkill.MultiplicativeStrategy),
				new CraftingElement<RiceItem>(typeof(CulinaryArtsEfficiencySkill), 10, CulinaryArtsEfficiencySkill.MultiplicativeStrategy),
				new CraftingElement<KelpItem>(typeof(CulinaryArtsEfficiencySkill), 5, CulinaryArtsEfficiencySkill.MultiplicativeStrategy),
            };
            this.CraftMinutes = CreateCraftTimeValue(typeof(SushiRecipe), Item.Get<SushiItem>().UILink(), 2, typeof(CulinaryArtsSpeedSkill)); 
            this.Initialize(Localizer.DoStr("Sushi"), typeof(SushiRecipe));
            CraftingComponent.AddRecipe(typeof(KitchenObject), this);
        }
    }
}